@@ -450,7 +450,7 @@ table       { font-size: 100%; }
     <a class="btn btn-warning" href='javascript:showCase(2)'>错误[ %(error)s ]</a>
     <a class="btn btn-danger" href='javascript:showCase(1)'>失败[ %(fail)s ]</a>
     <a class="btn btn-other" style="color: #fff;background-color: #6A614B;border-color: #6A614B" href='javascript:showCase(3)'>跳过[ %(skip)s ]</a>
-    <a class="btn btn-primary" href='javascript:void(0)'>通过率 [%(passrate)s ]</a>
+    <a class="btn btn-primary" href='javascript:void(0)'>通过率[%(passrate)s ]</a>
     </p>
 <table id='result_table' class="table table-condensed table-bordered table-hover">
 <colgroup>
@@ -756,7 +756,7 @@ class HTMLTestRunner(Template_mixin):
         if status:
             status = '，'.join(status)
             self.passrate = str("%.2f%%" % (float(result.success_count) / float(
-                result.success_count + result.failure_count + result.error_count + result.skipped_count) * 100))
+                result.success_count + result.failure_count + result.error_count) * 100))
         else:
             status = 'none'
         return [
